diff --git a/lib/SimpleSAML/Auth/ProcessingChain.php b/lib/SimpleSAML/Auth/ProcessingChain.php
index 7d8e5aa2b2d02af6ced5ab525044baf4950aa5d9..2b1aa72d2579d474964f1b2a51dd09023771b970 100644
--- a/lib/SimpleSAML/Auth/ProcessingChain.php
+++ b/lib/SimpleSAML/Auth/ProcessingChain.php
@@ -270,7 +270,7 @@ class ProcessingChain
     /**
      * Process the given state passivly.
      *
      * Modules with user interaction are expected to throw an \SimpleSAML\Error\NoPassive exception
      * which are silently ignored. Exceptions of other types are passed further up the call stack.
      *
      * This function will only return if processing completes.
@@ -299,7 +299,10 @@ class ProcessingChain
             try {
                 $filter->process($state);
             } catch (\SimpleSAML\Error\NoPassive $e) {
+                // @deprecated will be removed in 2.0
                 // Ignore \SimpleSAML\Error\NoPassive exceptions
+            } catch (\SimpleSAML\Module\saml\Error\NoPassive $e) {
+                // Ignore \SimpleSAML\Module\saml\Error\NoPassive exceptions
             }
         }
     }
@@ -270,7 +270,7 @@ class ProcessingChain
      * Process the given state passivly.
      *
-     * Modules with user interaction are expected to throw an \SimpleSAML\Error\NoPassive exception
+     * Modules with user interaction are expected to throw an \SimpleSAML\Module\saml\Error\NoPassive exception
      * which are silently ignored. Exceptions of other types are passed further up the call stack.
      *